==> MTOS-4.2-en.tar.gz: MTOS-4.2-en/mt-static/mt_ja.js <==
/* Movable Type language lexicon for ja localization. */

Lexicon['Add sub category'] = 'サブカテゴリを追加';
Lexicon['remove'] = '削除';
Lexicon['Make primary'] = 'メインカテゴリにする';
Lexicon['Last auto-save at [_1]:[_2]:[_3]'] = '[_1]:[_2]:[_3]に自動保存済み';
Lexicon['Remove'] = '削除';
Lexicon['Enter email address:'] = 'メールアドレスを入力:';
Lexicon['Are you certain you want to remove these [_1] roles? By doing so you will be taking away the permissions currently assigned to any users and groups associated with these roles.'] = 'これら[_1]つのロールをしてもよろしいですか? 削除してしまうと、これらのロールを通じて権限を付与されているすべてのユーザーとグループから権限を剥奪することになります。';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,entry,entries] from [_2]\<\/a\>'] = '[_2]に\<a href=\'[_3]\'\>[quant,_1,件,件]のブログ記事\<\/a\>を作成しています。';
Lexicon['Cancel'] = 'キャンセル';
Lexicon['No Preview Available'] = 'プレビューできません';
Lexicon['An error occurred while testing for the new tag name.'] = 'このタグは使用できません。';
Lexicon['[_1]Publish[_2] your site to see these changes take effect.'] = '設定を有効にするために[_1]再構築[_2]してください。';
Lexicon['[_1] &ndash; [_2] of [_3]'] = '[_1] &ndash; [_2] / [_3]';
Lexicon['View uploaded file'] = 'アップロードされたファイルを表示';
Lexicon['Loading...'] = 'ロード中...';
Lexicon['to mark as spam'] = 'スパムに指定';
Lexicon['[_1] [_2] - [_3] [_4]'] = '[_1][_2] - [_3][_4]';
Lexicon['Auto-saving...'] = '自動保存中...';
Lexicon['Are you certain you want to remove this role? By doing so you will be taking away the permissions currently assigned to any users and groups associated with this role.'] = 'このロールを本当に削除してもよろしいですか? ロールを通じて権限を付与されているすべてのユーザーとグループから権限を剥奪することになります。';
Lexicon['Are you sure you want to [_3] the [_1] selected [_2]?'] = '[_1]件の[_2]を[_3]してよろしいですか?';
Lexicon['delete'] = '削除';
Lexicon['You can only act upon a minimum of [_1] [_2].'] = '最低でも[_1]を選択してください。';
Lexicon['[_1:calMonth] [_2:calYear]'] = '[_2:calYear]年[_1:calMonth]';
Lexicon['You did not select any [_1] to [_2].'] = '削除する[_1]が選択されていません。';
Lexicon['to remove spam status'] = 'スパム指定を解除';
Lexicon['Enter URL:'] = 'URLを入力:';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all blogs?'] = 'タグ「[_2]」は既に存在します。すべてのブログで「[_1]」を「[_2]」にマージしてもよろしいですか?';
Lexicon['None selected'] = '選択されていません';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,comment,comments] from [_2]\<\/a\>'] = '[_2]に\<a href=\'[_3]\'\>[quant,_1,件,件]のコメント\<\/a\>があります。';
Lexicon['You must select an action.'] = 'アクションを選択してください。';
Lexicon['You did not select any [_1] [_2].'] = '[_2]する[_1]が選択されていません。';
Lexicon['disable'] = '無効に';
Lexicon['enable'] = '有効に';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\'?'] = 'タグ\'[_2]\'はすでに存在します。\'[_1]\'を\'[_2]\'に統合してもよろしいですか? ';
Lexicon['You can only act upon a maximum of [_1] [_2].'] = '最大で[_1]件しか選択できません。';
Lexicon['(None)'] = '(なし)';
Lexicon['Close'] = '閉じる';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all weblogs?'] = 'タグ\'[_2]\'はすでに存在します。\'[_1]\'を\'[_2]\'に統合してもよろしいですか?';
Lexicon['Are you sure you want to [_2] this [_1]?'] = '[_1]を[_2]してよろしいですか?';

==> MTOS-4.26-en.tar.gz: MTOS-4.26-en/mt-static/mt_ja.js <==
/* Movable Type language lexicon for ja localization. */

Lexicon['Add sub category'] = 'サブカテゴリを追加';
Lexicon['remove'] = '削除';
Lexicon['Make primary'] = 'メインカテゴリにする';
Lexicon['Are you sure you want to remove the [_1] selected [_2] from this group?'] = 'このグループから選択されている[_2]を削除してよろしいですか?';
Lexicon['Last auto-save at [_1]:[_2]:[_3]'] = '[_1]:[_2]:[_3]に自動保存済み';
Lexicon['Remove'] = '削除';
Lexicon['Enter email address:'] = 'メールアドレスを入力:';
Lexicon['Are you certain you want to remove these [_1] roles? By doing so you will be taking away the permissions currently assigned to any users and groups associated with these roles.'] = 'これら[_1]つのロールをしてもよろしいですか? 削除してしまうと、これらのロールを通じて権限を付与されているすべてのユーザーとグループから権限を剥奪することになります。';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,entry,entries] from [_2]\<\/a\>'] = '[_2]に\<a href=\'[_3]\'\>[quant,_1,件,件]のブログ記事\<\/a\>を作成しています。';
Lexicon['Cancel'] = 'キャンセル';
Lexicon['No Preview Available'] = 'プレビューできません';
Lexicon['An error occurred while testing for the new tag name.'] = 'このタグは使用できません。';
Lexicon['[_1]Publish[_2] your site to see these changes take effect.'] = '設定を有効にするために[_1]再構築[_2]してください。';
Lexicon['[_1] &ndash; [_2] of [_3]'] = '[_1] &ndash; [_2] / [_3]';
Lexicon['Are you sure you want to remove this [_1]?'] = '[_1]を削除してよろしいですか?';
Lexicon['View uploaded file'] = 'アップロードされたファイルを表示';
Lexicon['Loading...'] = 'ロード中...';
Lexicon['to mark as spam'] = 'スパムに指定';
Lexicon['[_1] [_2] - [_3] [_4]'] = '[_1][_2] - [_3][_4]';
Lexicon['Auto-saving...'] = '自動保存中...';
Lexicon['Are you certain you want to remove this role? By doing so you will be taking away the permissions currently assigned to any users and groups associated with this role.'] = 'このロールを本当に削除してもよろしいですか? ロールを通じて権限を付与されているすべてのユーザーとグループから権限を剥奪することになります。';
Lexicon['Are you sure you want to [_3] the [_1] selected [_2]?'] = '[_1]件の[_2]を[_3]してよろしいですか?';
Lexicon['delete'] = '削除';
Lexicon['You can only act upon a minimum of [_1] [_2].'] = '最低でも[_1]を選択してください。';
Lexicon['[_1:calMonth] [_2:calYear]'] = '[_2:calYear]年[_1:calMonth]';
Lexicon['Are you sure you want to remove this [_1] from this group?'] = 'このグループからこの[_1]を削除してよろしいですか?';
Lexicon['You have [quant,_1,registration,registrations] from [_2]'] = '[_2]に[quant,_1,件,件]の登録がありました。';
Lexicon['You did not select any [_1] to [_2].'] = '[_2]する[_1]が選択されていません。';
Lexicon['to remove spam status'] = 'スパム指定を解除';
Lexicon['Enter URL:'] = 'URLを入力:';
Lexicon['to remove'] = '削除する';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all blogs?'] = 'タグ「[_2]」は既に存在します。すべてのブログで「[_1]」を「[_2]」にマージしてもよろしいですか?';
Lexicon['None selected'] = '選択されていません';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,comment,comments] from [_2]\<\/a\>'] = '[_2]に\<a href=\'[_3]\'\>[quant,_1,件,件]のコメント\<\/a\>があります。';
Lexicon['Are you sure you want to remove the [_1] selected [_2]?'] = '選択されている[_2]を削除してよろしいですか?';
Lexicon['You must select an action.'] = 'アクションを選択してください。';
Lexicon['You did not select any [_1] [_2].'] = '[_2]する[_1]が選択されていません。';
Lexicon['You did not select any [_1] to remove.'] = '削除する[_1]が選択されていません。';
Lexicon['disable'] = '無効に';
Lexicon['enable'] = '有効に';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\'?'] = 'タグ\'[_2]\'はすでに存在します。\'[_1]\'を\'[_2]\'に統合してもよろしいですか? ';
Lexicon['You can only act upon a maximum of [_1] [_2].'] = '最大で[_1]件しか選択できません。';
Lexicon['(None)'] = '(なし)';
Lexicon['Close'] = '閉じる';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all weblogs?'] = 'タグ\'[_2]\'はすでに存在します。\'[_1]\'を\'[_2]\'に統合してもよろしいですか?';
Lexicon['Are you sure you want to [_2] this [_1]?'] = '[_1]を[_2]してよろしいですか?';
